==> scm_0.8.0-4.tar.gz: scm-0.8.0/src/opt/shortcutmkr/main.py <==
#!/usr/bin/python2.5
import sys
import os
import Image, ImageEnhance
import ImageDraw
import ImageFont
from PyQt4 import QtGui,QtCore
from PyQt4.QtGui import QIcon
from shortcutmkr import *
contact = ('')
num = ('')
ico = ('')
new = ('')
def watermark(im, mark, position, opacity=1):
    """Adds a watermark to an image."""
 
    layer = Image.new('RGBA', im.size, (0,0,0,0))
    if position == 'tile':
        for y in range(0, im.size[1], mark.size[1]):
            for x in range(0, im.size[0], mark.size[0]):
                layer.paste(mark, (x, y))
    elif position == 'scale':
        # scale, but preserve the aspect ratio
        ratio = min(
            float(im.size[0]) / mark.size[0], float(im.size[1]) / mark.size[1])
        w = int(mark.size[0] * ratio)
        h = int(mark.size[1] * ratio)
        mark = mark.resize((w, h))
        layer.paste(mark, ((im.size[0] - w) / 2, (im.size[1] - h) / 2))
    else:
        layer.paste(mark, position)
    # composite the watermark with the layer
    return Image.composite(layer, im, layer)

class MyForm(QtGui.QMainWindow):
	def __init__(self, parent=None):
		#build parent user interface
		QtGui.QWidget.__init__(self, parent)
		self.ui = Ui_ShortcutMaker()
		self.ui.setupUi(self)
		self.initUI()
				
		
	def initUI(self):
        	self.setWindowTitle('Shortcut Maker')
		
		#connect buttons
		QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.doCreate)
		QtCore.QObject.connect(self.ui.pushButton_2, QtCore.SIGNAL('clicked()'), self.doClearall)
		QtCore.QObject.connect(self.ui.pushButton_3, QtCore.SIGNAL('clicked()'), self.doDelete)
		QtCore.QObject.connect(self.ui.pushButton_4, QtCore.SIGNAL('clicked()'), self.doSelecticon)
		QtCore.QObject.connect(self.ui.pushButton_5, QtCore.SIGNAL('clicked()'), self.doIcontext)
		QtCore.QObject.connect(self.ui.pushButton_6, QtCore.SIGNAL('clicked()'), self.doIcondelete)
		QtCore.QObject.connect(self.ui.pushButton_7, QtCore.SIGNAL('clicked()'), self.doSelectfont)
		QtCore.QObject.connect(self.ui.checkBox_6, QtCore.SIGNAL("toggled(bool)"),self.copy)
		#QtCore.QObject.connect(self.ui.verticalScrollBar, QtCore.SIGNAL("sliderMoved()"),self.ymove)
		#QtCore.QObject.connect(self.ui.checkBox, QtCore.SIGNAL("toggled(bool)"),self.xterm)
		#QtCore.QObject.connect(self.ui.tabWidget, QtCore.SIGNAL('currentChanged(int)'), self.doTabChange)
	
	#def ymove(self):
		#px = int(self.ui.horizontalScrollBar.value())
		#self.ui.lineEdit_14.setText(px)
#radiobuttons	
	def copy(self):
		if self.ui.checkBox_6.isChecked():
			self.ui.lineEdit_4.setText(self.ui.lineEdit.text()) 
			self.ui.lineEdit_5.setText(self.ui.lineEdit_2.text())
	#def xterm(self):
		#if self.ui.checkBox.isChecked(): self.ui.lineEdit_9.setText("osso-xterm ''")
		#else: self.ui.lineEdit_9.clear()
			
		

#end radiobuttons	

#tabchange
	#def doTabChange(self):
	#	if self.ui.tabWidget.currentIndex() is  1:
	#		self.ui.lineEdit_4.setText('hello')
	#	else: self.ui.lineEdit_5.clear()
#endtabchange	


#begin button actions
	def doCreate(self):
		if self.ui.tabWidget.currentIndex() is  0:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_sms'
			contact  = self.ui.lineEdit.text()
			num = self.ui.lineEdit_2.text()
			fsock = open('/usr/share/applications/hildon/sms'+ contact +'.desktop', 'w') 
			
			saveout = sys.stdout                                     
	                            
	
			sys.stdout = fsock                                       
	
			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=SMS to ''' +contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","EnsureChannel","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"'''+num+'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.Text"},0,""))'
Icon='''+sm+'''''', 

			sys.stdout = saveout                                     

			fsock.close()
			contact = ('')
			num = ('')	

		if self.ui.tabWidget.currentIndex() is  1:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_call'
			contact  = self.ui.lineEdit_4.text()
			num = self.ui.lineEdit_5.text()
			fsock3 = open('/usr/share/applications/hildon/phone'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock3                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=Call '''+contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","Create","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"'''+num+'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.StreamedMedia"},0,""))'
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock3.close()
			contact = ('')
			num = ('')



		if self.ui.tabWidget.currentIndex() is  2:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_email'
			contact  = self.ui.lineEdit_6.text()
			num = self.ui.lineEdit_7.text()
			fsock2 = open('/usr/share/applications/hildon/email'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock2                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=EMAIL to '''+contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("com.nokia.modest","/com/nokia/modest", "com.nokia.modest","ComposeMail","ssssss", ("'''+num+'''","","","","",""))'
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock2.close()
			contact = ('')
			num = ('')


		if self.ui.tabWidget.currentIndex() is  3:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'filemanager_file_loading'
			if self.ui.checkBox.isChecked(): x = ('osso-xterm')
			contact  = self.ui.lineEdit_8.text()
			num = self.ui.lineEdit_9.text()
			fsock4 = open('/usr/share/applications/hildon/cmd'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock4                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Name='''+contact+'''
Exec='''+x+''' "'''+num+'''"
X-Osso-Type=application/x-executable
X-HildonDesk-ShowInToolbar=true
Type=Application
StartupNotify=true
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock4.close()
			contact = ('')
			num = ('')





	def doClearall(self):
		if self.ui.tabWidget.currentIndex() is  0:
			self.ui.lineEdit.clear()
			self.ui.lineEdit_2.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  1:
			self.ui.lineEdit_4.clear()
			self.ui.lineEdit_5.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  2:
			self.ui.lineEdit_6.clear()
			self.ui.lineEdit_7.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  3:
			self.ui.lineEdit_8.clear()
			self.ui.lineEdit_9.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)	
		if self.ui.tabWidget.currentIndex() is  5:
			self.ui.lineEdit_11.clear()
			self.ui.lineEdit_3.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)

	def doDelete(self):
		if self.ui.checkBox_2.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/sms'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_3.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_4.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_5.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/cmd'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		self.ui.checkBox_2.setChecked(False)
		self.ui.checkBox_3.setChecked(False)
		self.ui.checkBox_4.setChecked(False)
		self.ui.checkBox_5.setChecked(False)


	
#end button actions

	def doSelectfont(self):
		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
                    '/usr/share/fonts/')
		fontname = open(filename)
		fontn = (filename)
		self.ui.lineEdit_16.setText(fontn)
	

	def doSelecticon(self):
		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
                    '/usr/share/icons/')
		fname = open(filename)
		filen = (filename)
		#filen = filename.split(".")[0].split("/")[-1] 
		self.ui.lineEdit_3.setText(filen)
		self.ui.label_3.setPixmap(QtGui.QPixmap((filename)));
		self.ui.lineEdit_3.setModified(True)

	def doIcondelete(self):
		os.remove(self.ui.lineEdit_3.text())
		self.ui.lineEdit_11.clear()
		self.ui.lineEdit_3.clear()
		self.ui.label_3.clear()
		self.ui.lineEdit_3.setModified(False)
				
	
	def doIcontext(self):
		r = int(self.ui.lineEdit_13.text())
		g = int(self.ui.lineEdit_14.text())
		b = int(self.ui.lineEdit_15.text())
		px = int(self.ui.horizontalSlider.value())
		py = int(self.ui.verticalSlider.value())
		#fil = str('black')
		#if self.ui.checkBox_7.isChecked(): fil = ('white')
		siz = int(self.ui.lineEdit_12.text())		
		new = str(self.ui.lineEdit_3.text())
		mytext = str(self.ui.lineEdit_11.text())
		if self.ui.lineEdit_3.isModified(): fontPath = str(self.ui.lineEdit_16.text())
		else: fontPath = str("/usr/share/fonts/nokia/nosnb.ttf")
		sans16  =  ImageFont.truetype ( fontPath, siz )
		imn  =  Image.new ('RGBA', (48,48), (0,0,0,0))
		draw  =  ImageDraw.Draw ( imn )
		draw.text ( (px,py), mytext, font=sans16, fill =(int(r),int(g),int(b)) )
		if self.ui.lineEdit_3.isModified():
			im = Image.open(new)
		else: im =  Image.new ('RGBA', (48,48), (0,0,0,0))
		watermark(im, imn, 'scale', 1.0).save ('/usr/share/icons/scm'+mytext+".png")
		self.ui.lineEdit_3.setText('/usr/share/icons/scm'+mytext+".png")
		self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
		self.ui.lineEdit_3.setModified(True)
  	   
if __name__ == "__main__":
	app = QtGui.QApplication(sys.argv)
	myapp = MyForm()
	myapp.show()
	sys.exit(app.exec_())

==> scm_0.8.1-3.tar.gz: scm-0.8.1/src/opt/shortcutmkr/main.py <==
#!/usr/bin/python2.5
import sys
import os
import Image, ImageEnhance
import ImageDraw
import ImageFont
from PyQt4 import QtGui,QtCore
from PyQt4.QtGui import QIcon
from shortcutmkr import *
contact = ('')
num = ('')
ico = ('')
new = ('')
def watermark(im, mark, position, opacity=1):
    """Adds a watermark to an image."""
 
    layer = Image.new('RGBA', im.size, (0,0,0,0))
    if position == 'tile':
        for y in range(0, im.size[1], mark.size[1]):
            for x in range(0, im.size[0], mark.size[0]):
                layer.paste(mark, (x, y))
    elif position == 'scale':
        # scale, but preserve the aspect ratio
        ratio = min(
            float(im.size[0]) / mark.size[0], float(im.size[1]) / mark.size[1])
        w = int(mark.size[0] * ratio)
        h = int(mark.size[1] * ratio)
        mark = mark.resize((w, h))
        layer.paste(mark, ((im.size[0] - w) / 2, (im.size[1] - h) / 2))
    else:
        layer.paste(mark, position)
    # composite the watermark with the layer
    return Image.composite(layer, im, layer)

class MyForm(QtGui.QMainWindow):
	def __init__(self, parent=None):
		#build parent user interface
		QtGui.QWidget.__init__(self, parent)
		self.ui = Ui_ShortcutMaker()
		self.ui.setupUi(self)
		self.initUI()
				
		
	def initUI(self):
        	self.setWindowTitle('Shortcut Maker')
		
		#connect buttons
		QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.doCreate)
		QtCore.QObject.connect(self.ui.pushButton_2, QtCore.SIGNAL('clicked()'), self.doClearall)
		QtCore.QObject.connect(self.ui.pushButton_3, QtCore.SIGNAL('clicked()'), self.doDelete)
		QtCore.QObject.connect(self.ui.pushButton_4, QtCore.SIGNAL('clicked()'), self.doSelecticon)
		QtCore.QObject.connect(self.ui.pushButton_5, QtCore.SIGNAL('clicked()'), self.doIcontext)
		QtCore.QObject.connect(self.ui.pushButton_6, QtCore.SIGNAL('clicked()'), self.doIcondelete)
		QtCore.QObject.connect(self.ui.pushButton_7, QtCore.SIGNAL('clicked()'), self.doSelectfont)
		#QtCore.QObject.connect(self.ui.checkBox_6, QtCore.SIGNAL("toggled(bool)"),self.copy)
		#QtCore.QObject.connect(self.ui.verticalScrollBar, QtCore.SIGNAL("sliderMoved()"),self.ymove)
		#QtCore.QObject.connect(self.ui.checkBox, QtCore.SIGNAL("toggled(bool)"),self.xterm)
		QtCore.QObject.connect(self.ui.tabWidget, QtCore.SIGNAL('currentChanged(int)'), self.doTabChange)
	
	#def ymove(self):
		#px = int(self.ui.horizontalScrollBar.value())
		#self.ui.lineEdit_14.setText(px)
#radiobuttons	
	#def copy(self):
	#	if self.ui.checkBox_6.isChecked():
	#		self.ui.lineEdit_4.setText(self.ui.lineEdit.text()) 
	#		self.ui.lineEdit_5.setText(self.ui.lineEdit_2.text())
	#def xterm(self):
		#if self.ui.checkBox.isChecked(): self.ui.lineEdit_9.setText("osso-xterm ''")
		#else: self.ui.lineEdit_9.clear()
			
		

#end radiobuttons	

#tabchange
	def doTabChange(self):
		if self.ui.checkBox_6.isChecked():
			self.ui.lineEdit_4.setText(self.ui.lineEdit.text()) 
			self.ui.lineEdit_5.setText(self.ui.lineEdit_2.text())
		
#endtabchange	


#begin button actions
	def doCreate(self):
		if self.ui.tabWidget.currentIndex() is  0:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_sms'
			contact  = self.ui.lineEdit.text()
			num = self.ui.lineEdit_2.text()
			fsock = open('/usr/share/applications/hildon/sms'+ contact +'.desktop', 'w') 
			
			saveout = sys.stdout                                     
	                            
	
			sys.stdout = fsock                                       
	
			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=SMS to ''' +contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","EnsureChannel","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"'''+num+'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.Text"},0,""))'
Icon='''+sm+'''''', 

			sys.stdout = saveout                                     

			fsock.close()
			contact = ('')
			num = ('')	

		if self.ui.tabWidget.currentIndex() is  1:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_call'
			contact  = self.ui.lineEdit_4.text()
			num = self.ui.lineEdit_5.text()
			fsock3 = open('/usr/share/applications/hildon/phone'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock3                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=Call '''+contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","Create","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"'''+num+'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.StreamedMedia"},0,""))'
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock3.close()
			contact = ('')
			num = ('')



		if self.ui.tabWidget.currentIndex() is  2:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'general_email'
			contact  = self.ui.lineEdit_6.text()
			num = self.ui.lineEdit_7.text()
			fsock2 = open('/usr/share/applications/hildon/email'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock2                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=EMAIL to '''+contact+'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("com.nokia.modest","/com/nokia/modest", "com.nokia.modest","ComposeMail","ssssss", ("'''+num+'''","","","","",""))'
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock2.close()
			contact = ('')
			num = ('')


		if self.ui.tabWidget.currentIndex() is  3:
			if self.ui.lineEdit_3.isModified():
				ico = str(self.ui.lineEdit_3.text())
				sm = ico.split(".")[0].split("/")[-1]
			else: sm = 'filemanager_file_loading'
			if self.ui.checkBox.isChecked(): x = str('osso-xterm ');  a = str("'")
			else: x = str(''); a = str("")			
			contact  = self.ui.lineEdit_8.text()
			num = self.ui.lineEdit_9.text()
			fsock4 = open('/usr/share/applications/hildon/cmd'+ contact +'.desktop', 'w') 

			saveout = sys.stdout                                     
                            

			sys.stdout = fsock4                                       

			print '''[Desktop Entry]
Encoding=UTF-8
Name='''+contact+'''
Exec='''+x+''''''+a+''''''+num+''''''+a+'''
X-Osso-Type=application/x-executable
X-HildonDesk-ShowInToolbar=true
Type=Application
StartupNotify=true
Icon='''+sm+''''''

			sys.stdout = saveout                                     

			fsock4.close()
			contact = ('')
			num = ('')





	def doClearall(self):
		if self.ui.tabWidget.currentIndex() is  0:
			self.ui.lineEdit.clear()
			self.ui.lineEdit_2.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  1:
			self.ui.lineEdit_4.clear()
			self.ui.lineEdit_5.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  2:
			self.ui.lineEdit_6.clear()
			self.ui.lineEdit_7.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)
		if self.ui.tabWidget.currentIndex() is  3:
			self.ui.lineEdit_8.clear()
			self.ui.lineEdit_9.clear()
			self.ui.lineEdit_3.clear()
			self.ui.lineEdit_11.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)	
		if self.ui.tabWidget.currentIndex() is  5:
			self.ui.lineEdit_11.clear()
			self.ui.lineEdit_3.clear()
			self.ui.label_3.clear()
			self.ui.lineEdit_3.setModified(False)
			self.ui.checkBox.setChecked(False)

	def doDelete(self):
		if self.ui.checkBox_2.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/sms'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_3.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_4.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		if self.ui.checkBox_5.isChecked():
			contact = self.ui.lineEdit_10.text()
			os.remove('/usr/share/applications/hildon/cmd'+contact+'.desktop')
			contact = ('')
			num = ('')
			self.ui.lineEdit_10.clear()
		self.ui.checkBox_2.setChecked(False)
		self.ui.checkBox_3.setChecked(False)
		self.ui.checkBox_4.setChecked(False)
		self.ui.checkBox_5.setChecked(False)


	
#end button actions

	def doSelectfont(self):
		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
                    '/usr/share/fonts/')
		fontname = open(filename)
		fontn = (filename)
		self.ui.lineEdit_16.setText(fontn)
	

	def doSelecticon(self):
		filename = QtGui.QFileDialog.getOpenFileName(self, 'Open file',
                    '/usr/share/icons/')
		fname = open(filename)
		filen = (filename)
		#filen = filename.split(".")[0].split("/")[-1] 
		self.ui.lineEdit_3.setText(filen)
		self.ui.label_3.setPixmap(QtGui.QPixmap((filename)));
		self.ui.lineEdit_3.setModified(True)
		

	
				
	
	def doIcontext(self):
		r = int(self.ui.lineEdit_13.text())
		g = int(self.ui.lineEdit_14.text())
		b = int(self.ui.lineEdit_15.text())	
		icon = str(self.ui.lineEdit_3.text())
		mytext = str(self.ui.lineEdit_11.text())

		if self.ui.lineEdit_16.isModified(): fontPath = str(self.ui.lineEdit_16.text())
		else: fontPath = str("/usr/share/fonts/nokia/nosnb.ttf")
		if self.ui.lineEdit_3.isModified():
			im = Image.open(icon)
		else: im =  Image.new ('RGBA', (48,48), (0,0,0,0))		
		txt = mytext
		fontsize = 1  

		img_fraction = 1

		font = ImageFont.truetype(fontPath, fontsize)
		while font.getsize(txt)[0] < img_fraction*im.size[0]:
   
    			fontsize += 1
    			font = ImageFont.truetype(fontPath, fontsize)

		fontsize -= 1
		font = ImageFont.truetype(fontPath, fontsize)		
							
		icon = str(self.ui.lineEdit_3.text())
		if self.ui.lineEdit_16.isModified(): fontPath = str(self.ui.lineEdit_16.text())
		else: fontPath = str("/usr/share/fonts/nokia/nosnb.ttf")
				
		if self.ui.lineEdit_3.isModified():
			im = Image.open(icon)
		else: im =  Image.new ('RGBA', (48,48), (0,0,0,0))
		
		x, y = im.size
		
		wim = Image.new("RGBA", (x,y), (0,0,0,0))
		
		Image.composite(wim, im, wim ).save ('/usr/share/icons/scm'+mytext+".png")
		hope = Image.open('/usr/share/icons/scm'+mytext+".png")		
		bgim = Image.new("RGBA", (x,int(y + fontsize)), (0,0,0,0)) 
		
		draw = ImageDraw.Draw(bgim)
		bgim.paste(hope, (0,0,x,y))	
		draw.text ( (0,y), mytext, font=font, fill =(int(r),int(g),int(b)) )
		bgim.save ('/usr/share/icons/scm'+mytext+".png")
		self.ui.lineEdit_3.setText('/usr/share/icons/scm'+mytext+".png")
		self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
		self.ui.lineEdit_3.setModified(True)

	



	def doIcondelete(self):
		os.remove(self.ui.lineEdit_3.text())
		self.ui.lineEdit_11.clear()
		self.ui.lineEdit_3.clear()
		self.ui.label_3.clear()
		self.ui.lineEdit_3.setModified(False)
  	   
if __name__ == "__main__":
	app = QtGui.QApplication(sys.argv)
	myapp = MyForm()
	myapp.show()
	sys.exit(app.exec_())
